
Pipelining
==========

Single pipelining:

.. literalinclude:: /code/conds/syntax/pipe_single.py
    :language: py

You can also pipe multiple at the same time to avoid long
logical statements:

.. literalinclude:: /code/conds/syntax/pipe_multiple.py
    :language: py